@@ -59,6 +59,9 @@ webhook_install <- function(payload = NULL, sendmail = TRUE, mail_owner = TRUE,
     #formulate email message
     email_args <- create_email(result$success, result$output, payload, mail_owner)
     email_args$smtp_server = config("smtp.server")
+    email_args$use_ssl <- tryCatch({
+      config("smtp.use.ssl")
+    }, error = function(e){'no'})
 
     # try to send it
     tryCatch(do.call(send_email, email_args), error = function(e){
